.. kusto-tool documentation master file, created by
   sphinx-quickstart on Wed Jan 19 23:12:03 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to kusto-tool's documentation!
======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   overview
   reference


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
